Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _resolveFrom = require('resolve-from');

var _resolveFrom2 = _interopRequireDefault(_resolveFrom);

var _camelize = require('./camelize');

var _cssToObj = require('./cssToObj');

var _cssToObj2 = _interopRequireDefault(_cssToObj);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

//
// These visitors normalize the SVG into the primitives from react-primitives-svg:
//

// TODO: derrive known types from react-primitives-svg
// import { Svg } from 'react-primitives-svg';

/* eslint-disable no-param-reassign */
var knownTypes = ['Svg', 'Circle', 'ClipPath', 'Defs', 'Ellipse', 'G', 'Image', 'Line', 'LinearGradient', 'Path', 'Pattern', 'Polygon', 'Polyline', 'RadialGradient', 'Rect', 'Stop', 'Symbol', 'Text', 'TextPath', 'TSpan'];

/**
 * Converts first character of `str` to uppercase
 * @param str {String}
 * @returns String
 */
function toFirstUpper(str) {
  return str.charAt(0).toUpperCase() + str.substr(1);
}

/**
 * Converts `circle` to `Circle` if it is a known type
 * @param name {String}
 * @returns String
 */
function toMemberIdentifier(name) {
  // const knownTypes = Object.keys(Svg)
  // .filter(n => n.charAt(0) !== n.charAt(0).toLowerCase());
  var lname = name.toLowerCase();
  var cname = toFirstUpper(lname);
  if (knownTypes.includes(cname)) {
    return cname;
  }
  // Unknown node
  return null;
}

/**
 * Converts `<circle>` to `<Svg.Circle>` member expressions
 */

exports['default'] = function (t, ancestor, state) {
  return {
    JSXAttribute: function () {
      function JSXAttribute(path) {
        if (t.isJSXNamespacedName(path.node.name)) {
          // converts
          // <svg xmlns:xlink="asdf">
          // to
          // <svg xmlnsXlink="asdf">
          path.node.name = t.jSXIdentifier((0, _camelize.namespaceToCamel)(path.node.name.namespace.name, path.node.name.name.name));
        } else if (t.isJSXIdentifier(path.node.name)) {
          // converts
          // <tag class="blah blah1"/>
          // to
          // <tag className="blah blah1"/>
          if (path.node.name.name === 'class') {
            path.node.name.name = 'className';
          }

          // converts
          // <tag style="text-align: center; width: 50px">
          // to
          // <tag style={{textAlign: 'center', width: '50px'}}>
          if (path.node.name.name === 'style') {
            var csso = (0, _cssToObj2['default'])(path.node.value.value);
            var properties = Object.keys(csso).map(function (prop) {
              return t.objectProperty(t.identifier((0, _camelize.hyphenToCamel)(prop)), t.stringLiteral(csso[prop]));
            });
            path.node.value = t.jSXExpressionContainer(t.objectExpression(properties));
          }

          // converts
          // <svg stroke-width="5">
          // to
          // <svg strokeWidth="5">
          // don't convert any custom data-* attributes
          if (!path.node.name.name.startsWith('data-')) {
            path.node.name.name = (0, _camelize.hyphenToCamel)(path.node.name.name);
          }
        }
      }

      return JSXAttribute;
    }(),
    JSXOpeningElement: function () {
      function JSXOpeningElement(path) {
        var memberIdentifier = toMemberIdentifier(path.node.name.name);
        // console.log('"%s" => "%s"', path.node.name.name, memberIdentifier);
        if (!memberIdentifier) {
          var importPath = ancestor.node.source.value;
          var iconPath = state.file.opts.filename;
          var svgPath = (0, _resolveFrom2['default'])((0, _path.dirname)(iconPath), importPath);
          if (state.opts.verbose) {
            console.warn('WARNING: Removing incompatible node "%s" in file "%s".', path.node.name.name, svgPath);
          }
          path.parentPath.remove();
        } else {
          path.node.name = t.jSXMemberExpression(t.jSXIdentifier('Svg'), t.jSXIdentifier(memberIdentifier));
        }
      }

      return JSXOpeningElement;
    }()
  };
};